(this["webpackJsonp@dagit/app"]=this["webpackJsonp@dagit/app"]||[]).push([[9],{1053:function(e,n,t){"use strict";t.r(n),t.d(n,"FeatureFlagsRoot",(function(){return s}));var c=t(19),i=t(16),u=t(28),a=t(0),o=t(562),l=t(52),r=t(1),s=function(){var e=a.useState((function(){return Object(l.c)()})),n=Object(i.a)(e,2),t=n[0],s=n[1];a.useEffect((function(){Object(l.d)(t)})),Object(o.a)("Feature Flags");var d=function(e){s(t.includes(e)?t.filter((function(n){return n!==e})):[].concat(Object(c.a)(t),[e]))};return Object(r.jsxs)("div",{style:{padding:30,paddingTop:0},children:[Object(r.jsx)("h4",{children:"Experimental Features"}),Object(r.jsx)("div",{children:Object(r.jsx)(u.d,{label:"Debug Console Logging",checked:t.includes(l.a.flagDebugConsoleLogging),onChange:function(){return d(l.a.flagDebugConsoleLogging)}})}),Object(r.jsx)("div",{children:Object(r.jsx)(u.d,{label:"Pipeline name + mode tuples",checked:t.includes(l.a.flagPipelineModeTuples),onChange:function(){return d(l.a.flagPipelineModeTuples)}})})]})};n.default=s},562:function(e,n,t){"use strict";t.d(n,"a",(function(){return i}));var c=t(0),i=function(e){c.useEffect((function(){var n=document.title;return document.title=e,function(){document.title=n}}),[e])}}}]);
//# sourceMappingURL=9.7d0775d5.chunk.js.map